Monty Python's Flying Circus: Just the Words - Episode 13

# Episode Thirteen

Intermissions
Restaurant (abuse/cannibalism)
Advertisements
Albatross
Come back to my place
Me Doctor
Historical impersonations
Quiz programme - 'Wishes'
'Probe-around' on crime
Stonehenge
Mr Attila the Hun
Psychiatry - silly sketch
Operating theatre (squatters)

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Four undertakers carrying a coffin. The lid opens and the 'It's' man looks out.
It's Man | It's...
| Cut to large animated sign saying: 'Intermission'.
Voice Over | There will now be a short intermission.
| After this seven seconds of slightly speeded up Mantovani. Two animated cars race in and crash. Cut to animated opening credits. Cut to the same sign saying: 'Intermission'
Voice Over | There will now be a medium-sized intermission. (Same music, same speed, slightly longer.)
| Short animation, then cut to restaurant vestibule. He and she are already there, entering. She is nattering. The waiter is waiting.
She | Ooh I don't like this, Ooh I don't like that. Oh I don't think much to all this. Oh fancy using that wallpaper. Fancy using mustard. Oo is that a proper one? Oo it's not real. Oh I don't think it's a proper restaurant unless they give you finger bowls. Oo I don't like him. I'm going to have a baby in a few years.
He | Er, please excuse my wife. She may appear to be rather nasty but underneath she has a heart of formica. (the waiter grimaces) I'm sorry about that.
Waiter | That's all right sir, we get all sorts of lines in here. The head waiter will be along to abuse you in a few moments, and now if you'll excuse me I have to go and commit suicide.
He | Oh I'm sorry.
Waiter | It's all right. It's not because of anything serious.
| He exits. Shot off-screen and scream.
She | Quite frankly I'm against people who commit suicide, I don't like that sort of person at all. I'm plain people and I'm proud of it, my mother's the salt of the earth, and I don't take the pill 'cos it's nasty.
| The head waiter comes in.
He | Please excuse my wife, she may not be very beautiful, and she may have no money, and she may be a little talentless, boring and dull, but on the other hand ... (long pause) ... sorry I can't think of anything.
Head Waiter | Fine. I'm the head waiter. This is a vegetarian restaurant only, we serve no animal flesh of any kind. We're not only proud of that, we're smug about it. So if you were to come in here asking me to rip open a small defenseless chicken, so you could chew its skin and eat its intestines, then I'm afraid I'd have to ask you to leave.
He | No, no, no, no.
Head Waiter | Likewise if you were to ask us to slice the sides of a cow and serve it with small pieces of its liver ... (small tic developing, getting carried away) or indeed drain the life blood from a pig before cutting off one of its legs... or carve the living giblets from a sheep and serve them with the fresh brains, bowels, guts and spleen of a small rabbit... WE WOULDN'T DO IT. (reaction) Not for food anyway.
She | Quite frankly I'm against people who give vent to their loquacity by extraneous bombastic circumlocution. (they both look at her; pause) Oh I don't like that.
He | Sometimes Shirley I think you're almost human.
Head Waiter | (thinking) Do you know I still wet my bed?
He | Once I married someone who was beautiful, and young, and gay, and free. Whatever happened to her?
She | You divorced her and married me.
Head Waiter | I met my second wife at a second-wife-swapping party. Trust me to arrive late.
| Enter headmaster.
Headmaster | Always were late weren't you Thompson?
Head Waiter | Hello Headmaster. What are you doing here?
Headmaster | Fine, fine, fine, thank you. Fine, thank you. No more sherry for me don't you know. Warner House beat Badger House for the Second Cuppa, remarkable. We had to put most of the second form to sleep. No padre. Bad business. They were beginning to play with themselves. Still... You haven't seen my wife anywhere have you?
Head Waiter | No.
Headmaster | Oh thank God for that. (exits)
She | Oh I don't like him. Do you know what I mean. Do you know what I mean. I mean do you know what I mean. Do you know what I mean. Do you know what I mean. I mean do you know what I mean. All men are the same.
| Enter prologue, long white Greek robes, long white beard, holding a large staff.
Prologue | Imagine not that these four walls contain the Mighty Owl of Thebes. For, gentles all, beauty sits most closely to them it can construe...
Head Waiter | No it doesn't.
Prologue | Sorry. (he exits)
Head Waiter | Fine. Would you care for a glass of blood? Oh what a giveaway.
She | No, we'd like to see the menu please. I don't think it's a proper restaurant unless you have a proper menu and anyway I might be pregnant.
He | Perhaps you'd care for a drink?
She | Ever since you've married me, Douglas, you've treated me like an albatross.
| A waiter enters pushing a large serving dish with a semi-naked Hopkins sitting unconcernedly in it.
Hopkins | Evening.
He | Good evening.
Hopkins | I hope you're going to enjoy me this evening. I'm the special. Try me with some rice.
He | I beg your pardon?
Hopkins | A Hopkins au gratin a la chef.
He | Ah, oh how do you... (makes to shake hands)
Hopkins | (skittishly) Don't play with your food.
She | (examining him) I don't like that. There's dust on here. I don't think it's a proper meal without a pudding. My husband's an architect.
Hopkins | Oh, one word of warning, sir, a little tip. (lowering voice) Don't have any of the vicar over there. (cut to vicar sitting thin and unhappy in a pot) He's been here two weeks and nobody's touched him. 'Nuff said?
He | Yes thank you.
Hopkins | Well I must get along or I'll spoil. Janet - to the kitchen.
Waiter | There's a dead bishop in the lobby, sir.
Head Waiter | I don't know who keeps bringing them in here.
She | Oh I don't like that. I think it's silly. It's not a proper sketch without a proper punchline. I mean I don't know much about anything, I'm stupid. I'm muggins. Nobody cares what I think. I'm always the one that has to do everything. Nobody cares about me. Well I'm going to have a lot of bloody babies and they can bloody well care about me. Makes you sick half this television. They never stop talking, he'll be the ruination of her, rhythm method.
| Cut to animated sign saying 'Intermission '.
Voice Over | There will now be a whopping great intermission, during which small ice creams in very large boxes will be sold. Another way we can drive people away from the cinema is by showing you advertisements.
| Intermission changes to adverts. Animated title: 'Pearls For Swine Presents'. Shots of various cars with young ladies posing on them.
Voice Over | Do you like this? Or how about this? Or perhaps you prefer this latest model. Then why not come to us. We supply only the very best models. (a card saying 'Soho Motors 2nd floor' an a board with advertisement cards for 'Rita' etc.; cut to a restaurant) After the show why not visit the La Gondola Restaurant. Just two minutes from this performance. The manager Mr Luigi Vercotti will be pleased to welcome you and introduce you to a wide variety of famous Sicilian delicacies. (as Vercotti poses for the camera policemen bundle his staff and several half-dressed girls through and out of the restaurant) Here you can relax in comfort in friendly surroundings. Or if you wish, you may drink and dance till midnight. At the La Gondola Restaurant you can sample all the spicy pleasures of the Mediterranean. The head waiter will be pleased to show you his specialities. Or why not ask the cook for something really hot? (the police remove a chef carrying a 8mm projector and film) Yes, for an evening you will never forget - it's the La Gondola Restaurant, Chelsea, Parkhurst, Dartmoor and the Scrubs. (the police remove Mr Vercotti)
| 'Pearls for Swine' closing title. Cut to corner of cinema. A man in an ice-cream girl's uniform is standing in a spotlight with an ice-cream tray with an albatross on it.
Man | Albatross! Albatross! Albatross!
| A cutomer approaches him.
Person | Two choc-ices please.
Man | I haven't got choc-ices. I only got the albatross. Albatross!
Person | What flavour is it?
Man | It's a bird, innit? It's a bloody sea bird . .. it's not any bloody flavour. Albatross!
Person | Do you get wafers with it?
Man | Course you don't get bloody wafers with it. Albatross!
Person | How much is it?
Man | Ninepence.
Person | I'll have two please.
Man | Gannet on a stick.
| The camera zooms past back onto the screen. On screen appears another 'Intermission' sign.
First Voice Over | There will now be a very short...
| The intermission sign explodes.
| ANIMATED CAPTIONS: 'NOW SHOWING AT OTHER DANK CINEMAS' 'AT THE PORTNOY CINEMA PICCADILLY' 'WINNER OF THE GOLDEN PALM, TORREMOLINOS' 'RAINWEAR THROUGH THE AGES' 'COMING SOON' 'AT THE JODRELL CINEMA, COCKFOSTERS'
Second Voice Over | And CAPTION: 'The management regrets that it will not be showing a feature film this evening as it eats into the profits'
| Cut to the Queen on horseback; first few bars of National Anthem. Cut to Person sitting in cinema seat clutching albatross.
Person | Well that's quite enough of that. And now a policeman near Rottingdeans ... Albatross!
| Cut to a policeman standing in a street man comes up to him.
Man | Inspector, inspector.
Inspector | Uh huh.
Man | I'm terribly sorry but I was sitting on a park bench over there, took my coat off for a minute and then I found my wallet had been stolen and £15 taken from it.
Inspector | Well did you er, did you see anyone take it, anyone hanging around or...
Man | No no, there was no one there at all. That's the trouble.
Inspector | Well there's not very much we can do about that, sir.
Man | Do you want to come back to my place?
Inspector | ... Yeah all right.
| Women's Institute applauding.
| Cut to a man on a bench in casualty ward set.
Man | Albatross
| Doctor and sister enter and go up to him.
Doctor | Mr. Burtenshaw?
Man | Me, Doctor?
Doctor | No, me doctor, you Mr. Burtenshaw.
Man | My wife, doctor?
Doctor | No, your wife patient, me Doctor.
Sister | Come this way please.
Man | Me, Sister?
Doctor | No. She Sister. Me Doctor. You Mr. Burtenshaw.
| Nurse enters.
Nurse | Doctor Walters?
Doctor | Me, Nurse. (to sister) You Mr. Burtenshaw. (to man) She Sister. You Doctor. (to nurse)
Nurse | No, doctor.
Doctor | No Doctor? Call ambulance. Keep warm.
Sister | Drink, doctor?
Doctor | Drink doctor. Eat Sister. Cook Mr. Burtenshaw. Nurse me.
Nurse | You, doctor?
Doctor | Me Doctor. You Mr. Burtenshaw. She Nurse.
Man | But my wife, Nurse.
Doctor | Your wife not nurse. She Nurse. Your wife patient. Be patient. She Nurse. Your wife. Me doctor. Yew Tree. U-trecht. U-trillo, U Thant, Euphemism. Me Doctor. (knight walks in quickly and hits him over the head with a chicken) Albatross!
| Women's Institute applaud.
| Cut to film of Gumbys (vox pop)
Gumby | I would like to meet someone of superior intelligence.
Second Gumby | I would like to hear the sound of two bricks being bashed together.
Gumby | I would like to see John the Babtist's impersonation of Graham Hill.
| Cut to historical impersonation sketch. Big zoom in to linkman. Glittery linkman set, showbizzy music and applause.
Voice Over | Yes, it's Historical Impersonations. When you in the present can make those in the past stars of the future. And here is your host for tonight - Wally Wiggin.
| CAPTION: 'HISTORICAL IMPERSONATIONS' Fade applause and music.
Wiggin | Hello, good evening and welcome to Historical Impersonations. And we kick off tonight with Cardinal Richelieu and his impersonation of Petula Clark.
| Cut to Cardinal Richelieu, he mimes to the phrase from the record.
Richelieu | 'Don't sleep in the subway darling and don't stand in the pouring rain'.
| Vast applause.
Wiggin | Cardinal Richelieu - sixteen stone of pure man. And now your favourite Roman Emperor Julius Caesar as Eddie Waring.
| Cut to Caesar; cloud effects behind.
Caesar | (in Waring voice) Tota gallia divisa est in tres partes Wigan, Hunslett and Hull Kingston Rovers.
| Cut back to Wiggin.
Wiggin | Well done indeed, Julius Caesar, a smile, a conquest and a dagger up your strap. Our next challenger comes all the way from the Crimea. It's the very lovely Florence Nightingale as Brian London.
| Florence Nightingale (Graham) stands there with a lamp, simpering femininely. A boxing bell goes, slight pause, then she is hit on the side of the cheek with a boxing glove, and fallls straight on her back. Cut back to Wiggin.
Wiggin | And now for our most ambitious attempt tonight - all the way from Moscow in the USS of R - Ivan the Terrible as a sales assistant in Freeman, Hardy and Willis.
| In a shoe department. Three people are sitting in chain, only the middle one is a dummy. Ivan the Terrible comes in and splits the man in the middle in half with an immense two-handed sword: the model splits in two.
Wiggin | And now W. G. Grace as a music box.
| ANIMATION: Still picture of W. G. Grace. Slowly his head starts to revolve as a musical box plays Swiss-type music. Cut back to Wiggin.
Wiggin | And now it's France's turn. One of their top statesmen, Napoleon as the R101 disaster.
| Cut to a sky backgrouned Napoleon comes into frame horizontally, moving along a wire very slowly. In each hand he has a small propeller. A sign hangs below his belly saying R101. Marseillaise plays. As he passes out of shot there is an explosion.
Wiggin | And now it's request time.
| Cut to Gumby.
Gumby | I would like to see John the Baptist's impersonation of Graham Hill.
| A head on a platter is pulled by a string across the floor. We hear brm, brm, brm, noises. The head of John the Baptist has a Graham Hill moustache, obviously stuck on. Women's Institute applaud.
Wiggin | And now a short intermission during which Marcel Marceau will impersonate a man walking against the wind.
| Marcel Marceau (Graham) walks against the wind.
Wiggin | And now Marcel will mime a man being struck about the head by a sixteen-ton weight.
| Cut to him starting the mime. He doesn't get very far as a sixteen-ton weight is dropped on his head. Cut to Wembley crowd cheering. Cut to interviewer and two small boys.
Interviewer | (gently) What's your name?
Eric | Eric.
Interviewer | Would you like to have a sixteen-ton weight dropped on top of you, Eric?
Eric | Don't know.
| Brief stock shot of theatre audience applauding.
Interviewer | How about you?
Michael | I want to have.
Interviewer | What do you want to have?
Michael | I want to have... I want to have Racquel Welch dropped on top of me.
Interviewer | Dropped on top of you.
Michael | Oh yes, not climbing.
Eric | She's got a big bottom.
| Applause stock shot. Cut to interviewer and two city gents (on their knees)..
Interviewer | And what's your name?
Trevor | Trevor Atkinson.
Interviewer | And how old are you, Trevor?
Trevor | I'm forty-two.
| Applause stock shot.
Interviewer | (to other city gent) Are you a friend of Trevor's?
City Gent | Yes, we're all colleagues from the Empire and General Insurance Company.
Interviewer | And what do you do?
City Gent | Well I deal mainly with mortgage protection policies, but I also do certain types of life assurance.
Interviewer | Now if you and your pal had one big wish, Trevor, what would you like to see on television?
Trevor | I'd like to see more fairy stories about the police.
| Fairy godmother trips lightly into shot.
Fairy | And so you shall.
| Cut to open country. A policeman cycles up and parks his bike. From the saddlebag he takes a burglar's outfit - striped jersey, cap, and trousers. He lays them out on the ground, and inflates them with a bicycle pump. The inflated burglar runs away in speeded-up motion. The policeman blows his whistle. Three more policemen appear out of nowhere. He points forward and the four of them move off in a pixilated motion after the burglar. The burglar runs across moorland; the policemen follow him. Dick Barton theme music. The burglar lures the policemen into a large packing crate, slams the door on them and nails on it a label: 'Do not open until Christmas'. In the background a policeman with a fairy tutu appears suddenly out of thin air. He waves his wand at the burglar, who disappears. Cut to policeman, with wand, standing in a street.
Policeman | Yes, we in Special Crime Squad have been using wands for almost a year now. You find it's easy to make yourself invisible. You can defy time and space, and you can turn violent criminals into frogs. Something which you could never do with the old truncheons.
| 'Panorama' music and still photos of policemen in tutus. CAPTION: 'PROBE AROUND' Cut to interviewer at desk of 'Panorama' type set-up.
First Interviewer | Yes, tonight 'Probe Around' takes a look at crime...
| A shot rings out and he slumps backward. A second interviewer runs into shot from behind camera with smoking gun.
Second Interviewer | I'm sorry about that, but I always introduce this programme, not him. (he pushes the first interviewer off his chair with his foot and takes his place) Yes, tonight 'Probe Around' takes a look at Crime. Is it true that the police are using dachshunds to combat the crime wave? And can the head of the Vice Squad turn himself into an albatross whenever he wants to? Just what are the police up to?
| Cut to close-up of a constable reading big book. He is very, very, very stupid.
Policeman | Oh, I'm up to page 39, where Peter Pan first manifests himself.
| Cut back to interviewer.
Second Interviewer | With me now is Inspector Harry H 'Snapper' Organs of 'H' Division.
| Cut to another part of the 'Panorama' set. Detective Inspector Organs is sitting next to a Viking.
Organs | Good evening.
| Cut back to interviewer and hereafter cross cut between them.
Interviewer | Er, Inspector, I believe you are encouraging magic in the Police Force?
Organs | That is correct. (as he speaks we notice he is sticking pins into a model of a burglar) The criminal mind is a strange and contorted one. Good evening. The mind is subject to severe mental stresses. Good evening. Guilt fears abound, good evening. In the subconscious in this state, one of our lads, with a fair training in the black arts can scare the fertilizer out of them.
Interviewer | Just how are the police combating the increase with the use of the occult? Ex-King Zog of Albania reports ...(phone rings) Well we seem to have lost ex-King Zog there, but who cares. Just what kinds of magic are the police introducing into their crime prevention techniques?
| Cut to four chief constables huddled round an Ouija board. The have their fingers on a tumbler which moves slowly from one letter to the next.
Policemen | U-P Y-O-U-R-S.
Second Policeman | Up yours? What a rude Ouija board!
| Cut to more film: policeman with wand. By pointing the wand at illegally parked cars he makes them disappear. Another policeman on the pavement helping an old lady across road. He looks to see if the road is clear, waves his wand and she jumps across to other side. Another street: a police siren is heard then five policemen on broom sticks appear from round corner and disappear across frame.
| Cut to police dancing round Stonehenge. A burglar is bound to a stone altar. Mix to picture of same thing in newspaper which is being read by a chief constable in his office.
Chief Constable | Now this is the kind of thing that gives the police a bad name, sergeant.
| Pull out further to reveal police sergeant in long shimmering slim-fitting ladies evening gown, diamante handbag and helmet.
Sergeant | I know, sir.
| Intercom buzzer goes on desk.
Chief Constable | (depressing knob) Yes, Beryl?
Beryl | (male voce) Attila the Hun to see you, sir.
Chief Constable | Who?
Beryl | Attila the Hun, sir.
Chief Constable | Oh botherkins! Er, constable, go and see to him will you?
Sergeant | What! In this dress?
Chief Constable | Oh all right, I'll go.
Sergeant | Oh, I have got a little green pinny I could wear...
Chief Constable | No, no, no, I'll go. You stay here.
Sergeant | Oh goody! I can get on with the ironing.
| The chief constable walks through the door into the reception area of the police station. There is a policeman behind the counter and a little insignificant man is standing waiting.
Chief Constable | (to policeman) Right where is he?
Beryl | Over there, sir.
Chief Constable | Right, er, all right sergeant leave this to me. Er, now then sir, you are Attila the Hun.
Attila the Hun | That's right, yes. A. T. Hun. My parents were Mr and Mrs Norman Hun, but they had a little joke when I was born.
Chief Constable | Yes well, Mr Hun ...
Attila | Oh! Call me 'The', for heaven's sake!
Chief Constable | Oh well, The... what do you want to see us about?
Attila | I've come to give myself up.
Chief Constable | What for?
Attila | Looting, pillaging and sacking a major city.
Chief Constable | I beg your pardon?
Attila | Looting, pillaging, sacking a major city, and I'd like nine thousand other charges to be taken into consideration, please.
Chief Constable | I say, excuse me, Mr Hun. (he takes his hat off, removes his moustache, puts it in the hat and puts the hat back on) Have you any objection to taking a breath test?
Attila | Oh, no. No, no, no, no.
Chief Constable | Right, er, sergeant will you bring the Hunalyser, please?
| The constable produces a breathalyser.
Beryl | Here we are, sir.
| Hands it to the chief constable.
Chief Constable | Er, how's it work?
Beryl | Well he breathes into it, sir, and the white crystals turn lime green. Then he is Attila the Hun, sir.
Chief Constable | I see. Right. Would you mind breathing into this Mr Hun?
Attila | Right. (blows into bag)
Chief Constable | What if nothing happens, sergeant?
Beryl | He's Alexander the Great!
Chief Constable | Ha, ha! Caught you, Mr A. T. Great!
Attila | (who is now Alexander the Great) Oh curses! Curses! I thought I was safe, disguised as Attila the Hun.
Chief Constable | Oh perhaps so, but you made one fatal mistake... you see, this wasn't a Hunalyser... it was an Alexander the Greatalyser Take him away, Beryl!
| Cut to letter (as used for 'Xmas night with the stars' after pet shop. I'm sorry...as not used in 'Xmas night with the stars').
First Voice Over | Dear Sir, I object very strongly to that last scene, and to the next letter.
| Cut to second letter.
Second Voice Over | Dear Sir, I object to being objected to by the last letter, before my drift has become apparent. I spent many years in India during the last war and am now a part-time notice board in a prominent public school. Yours etc., Brigadier Zoe La Rue (deceased). PS Aghhh!
| Cut to third letter.
Third Voice Over | Dear Sir, When I was at school, I was beaten regularly every thirty minutes, and it never did me any harm - except for psychological maladjusunent and blurred vision. Yours truly, Flight Lieutenant Ken Frankenstein (Mrs).
| Animation link runs into a psychiatrist's consulting room. The psychiatrist at his desk. The door opens and a receptionist looks in.
Receptionist | Dr Larch ... there's a Mr Phelps to see you.
Psychiatrist | Er, nurse!
Receptionist | Yes?
Psychiatrist | (whispering) Er, you don't think you should make it clear that I'm a psychiatrist?
Receptionist | What?
Psychiatrist | Well, I could be any type of doctor.
Receptionist | Well I can't come in and say 'Psychiatrist Larch' or 'Dr Larch who is a psychiatrist'. Oh, anyway look, it's written on the door.
Psychiatrist | (still whispering) That's outside.
Receptionist | Well, I don't care, you'll just have to do it yourself. (she leaves)
Psychiatrist | (goes 'brr brr', then picks up phone) Hello. Er, no, wrong number I'm afraid, this is a psychiatrist speaking. Next please. (knock at the door) Er, come in.
| Phelps comes in dressed as Napoleon, with a parrot on his head, and a leash with nothing on it.
Phelps | Bow, wow, wow.
Psychiatrist | Ah Mr Phelps. Come on in, take a seat. Now what seems to be the matter?
Phelps | No, no, no. No. No.
Psychiatrist | I'm sorry?
Phelps | Oh can't you do better than that? I mean it's so predictable I've seen it a million times. Knock, knock, knock come in, ah Mr Phelps take a seat. I've seen it and seen it.
Psychiatrist | Well look will you please sit down and do your first line.
Phelps | No. No. I've had enough. I've had enough. (he exits)
Psychiatrist | I can't even get it started.
Phelps | (off) Albatross!
Psychiatrist | Shut up! Oh it drives me mad.
| Cut to a man in limbo: Mr Notlob.
Notlob | A mad psychiatrist, that'd be new.
| Cut back to the psychiatrist.
Psychiatrist | Next please.
| Knocking at door. Psychiatrist is about to call when he picks up a thesaurus and thumbs through it.
Psychiatrist | Cross the threshold, arrive, ingress, gain admittance, infiltrate. (Notlob enters in an ordinary suit) Ah Mr Notlob, ah park your hips, on the sitting device.
Notlob | (to camera) It is a mad psychiatrist.
Psychiatrist | I'm not. I'm not. Come on in. Take a seat. What's, what's the matter?
| Cut to Napoleon in limbo; he blows a raspberry.
Psychiatrist | Now what's the matter?
Notlob | Well I keep hearing guitars playing and people singing when there's no one around.
Psychiatrist | Yes, well this is not at all uncommon. In certain mental states we find that auditory hallucinations occur which are of a most ... (he steps suddenly and listens; the sound of 'We're all going to the zoo tomorrow' is heard) Is that 'We're all going to the zoo tomorrow'?
Notlob | Yes. Yes.
Psychiatrist | Is it always that?
Notlob | No.
Psychiatrist | Well that's something.
Notlob | But it's mainly folk songs.
Psychiatrist | (concerned) Oh my God.
Notlob | Last night I had 'I'll never fall in love again' for six hours.
Psychiatrist | Well look, I think I'd better have a second opinion on this. I want you to see a colleague of mine, a specialist in these sort of things, who has an office very much like this one as a matter of fact.
| Jump cut off same office now occupied by a surgeon. Start on portrait which has moustache and beard and glasses being added by surgeon.
Surgeon | Brr brr (picks up phone) No, no wrong number I'm a colleague of his, a surgeon, who specializes in these kind of things. Yes thank you very much. (replaces phone) Next please. (knock at door) Come in. (Notlob enters; 'Going to the zoo' is faintly heard) Ah come in, please take a seat. (cut to terribly quick shot of Napoleon, then back) My colleague who has a similar office has explained your case to me (he is rising from seat) Mr Notlob, as you know I am a leading Harley Street surgeon as seen on television. (he puts needle down on ancient gramophone; Dr Kildare theme begins playing) I'm afraid I'm going to have to operate. It's nothing to worry about although it is extremely dangerous. I shall be juggling with your life, I shall be playing ducks and drakes with your very existence, I shall be running me mitts over the pith of your marrow. Yes! These hands, these fingers, these sophisticated organs of touch, these bunches of five, these maulers, these German bands that have pulled many a moribund unfortunate back from the very brink of Lazarus's box. No, it was Pandora's box wasn't it? Well anyway these mitts have earned yours truly a lot of bread. So if you'll just step through here I'll slit you up a treat.
Notlob | What?
Surgeon | Mr Notlob, there's nothing wrong with you that an expensive operation can't prolong.
| Cut to operating theatre. The conversation and the guitar can still be heard. Notlob is on the table. His head is real but the rest of the body is false. Table is covered with green cloth for reality. Surgeon is swabbing. 'Going to the zoo' is still audible.
Surgeon | Right, I'm ready to make the incision. Knife please, sister (takes knife) What's that supposed to be. Give me a big one.. (takes big knife and strops it on steel sharpener) . . . oh I do enjoy this. Right. (he stabs the body and makes a slit four feet long) Oh what a great slit. Now, gentlemen, I am going to open the slit.
| He pulls it apart. The song gets louder. The head of a squatter pops out.
Squatter | Too much man, groovy, great scene. Great light show, baby.
Surgeon | What are you doing in there?
Squatter | We're doing our own thing, man.
Surgeon | Have you got Mr Nottob's permission to be in there?
Squatter | We're squatters, baby.
Surgeon | What? (to nurse about Notlob) Nurse, wake him up. (she slaps his face)
Squatter | Don't get uptight, man. Join the scene and other phrases. Money isn't real.
Surgeon | It is where I'm standing and it blows my mind, young lad. (looks inside Notlob) Good Lord! Is that a nude woman?
Squatter | She's doing an article on us for 'Nova', man.
Girl | (her head also appearing through slit) Hi everyone. Are you part of the scene?
Surgeon | Are you rolling your own jelly babies in there?
Notlob | (waking up) What's going on? Who are they?
Surgeon | That's what we are trying to find out.
Notlob | What are they doing in my stomach?
Surgeon | We don't know. Are they paying you any rent?
Notlob | Of course they're not paying me rent!
Squatter | You're not furnished, you fascist.
Notlob | Get them out!
Surgeon | I can't.
Notlob | Get them out.
Surgeon | No I can't. Not, not without a court order.
Indian | (also appearing) Shut up. You're keeping us awake.
| CAPTION: 'ONE COURT ORDER LATER' Some policemen walk in.
First Policeman | (into slit) You are hereby ordered to vacate Mr Notlob forthwith. And or.
Squatter | Push off, fuzz.
Policeman | Right, that's it, we're going in. Release the vicious dogs. (dives into slit)
| ANIMATION:
Animated Character | What a terrible way to end a series. Why couldn't it end with something like this? (a short piece of confusing animation later) Now there's an ending for you. Romance. Laughter.
| Cut to film of 'It's' man being pursued by undertaker; roll credits over. CAPTION: 'INTERMISSION'
Voice Over | When this series returns it will be put out on Monday mornings as a test card and will be described by 'Radio Times' as a history of Irish agriculture.